@@ -1,4 +1,4 @@
-# Copyright (C) 2010-2022 by the Free Software Foundation, Inc.
+# Copyright (C) 2010-2023 by the Free Software Foundation, Inc.
 #
 # This file is part of GNU Mailman.
 #
@@ -25,7 +25,7 @@ from click.testing import CliRunner
 from contextlib import ExitStack, suppress
 from datetime import timedelta
 from flufl.lock import Lock, TimeOutError
-from importlib_resources import path
+from importlib.resources import path
 from io import StringIO
 from mailman.bin import master
 from mailman.config import config
